%-------------------------------------------------------------------------
%
%                        TINIndex Analysis Package
%
%         A software package for the generation of TIN terrain models
%
%                        Ralph M. Parsons Laboratory
%                   Massachusetts Institute of Technology
%   
%
%                           Beta Release, 3/2002
%
% 
%    slopearea.m:  MATLAB script to plot DEM and TIN slopearea curve    
%
%-------------------------------------------------------------------------


%Get watershed name and access file in output directory
watershed = input('Enter watershed name: ', 's');
directory = strcat(watershed,'output');
fileg = strcat(directory, '/slopeareagrid.txt');
filet = strcat(directory, '/slopeareatin.txt');

%Read in Arc/Info unload table into array
gridtable = dlmread(fileg, ',');
tintable = dlmread(filet, ',');

%Get min and max 
maxgrid = max(gridtable(:,3));
maxtin = max(tintable(:,3));
mingrid = min(gridtable(:,2));
mintin = min(tintable(:,2));
low = min(mingrid, mintin);
high = max(maxgrid, maxtin);

%Get range midpoint
gridtable(:,5) = (gridtable(:,2) + gridtable(:,3))/2;
tintable(:,5) = (tintable(:,2) + tintable(:,3))/2;

%Select non-zero entries
nonzg = find(gridtable(:,4)>0);
nonzt = find(tintable(:,4)>0);

%Plot histograms comparison
figure;
loglog(gridtable(nonzg,5), gridtable(nonzg,4), 'ro-');
hold;grid;
loglog(tintable(nonzt,5), tintable(nonzt,4), 'bx-');
legend('DEM','TIN');
xlabel('Contributing area (m^2)');
ylabel('Slope (degrees)');
title('Comparison of Slope-Area Diagrams');

%Clean up
clear;
